==> PathOfBuildingCommunity-Portable-2.7.0.zip: Data/Uniques/wand.lua <==
﻿-- Item data (c) Grinding Gear Games

return {
-- Weapon: Wand
[[
Abberath's Horn
Goat's Horn
Variant: Pre 2.3.0
Variant: Current
Requires Level 6, 29 Int
Implicits: 2
{variant:1}(9-12)% increased Spell Damage
{variant:2}(10-14)% increased Spell Damage
(20-30)% increased Fire Damage
Adds (4-6) to (8-12) Fire Damage to Spells
(40-60)% increased Global Critical Strike Chance
+10 Life Gained on Killing Ignited Enemies
25% reduced Ignite Duration on Enemies
]],[[
Apep's Rage
Opal Wand
Variant: Pre 2.3.0
Variant: Pre 3.7.0
Variant: Pre 3.11.0
Variant: Current
Requires Level 62, 212 Int
Implicits: 2
{variant:1}(17-20)% increased Spell Damage
{variant:2,3,4}(38-42)% increased Spell Damage
{variant:1,2}Adds (50-65) to (90-105) Chaos Damage to Spells
{variant:3,4}Adds (90-130) to (140-190) Chaos Damage to Spells
(25-30)% increased Cast Speed
+(5-10)% to Chaos Resistance
{variant:1,2,3}40% increased Mana Cost of Skills
{variant:4}+40 to Total Mana Cost of Skills
{variant:3,4}Poisons you inflict deal Damage 20% faster
]],[[
Ashcaller
Quartz Wand
Variant: Pre 3.8.0
Variant: Current
Requires Level 18, 65 Int
Implicits: 1
(18-22)% increased Spell Damage
10% chance to Trigger Level 8 Summon Raging Spirit on Kill
{variant:1}Adds (10-14) to (18-22) Fire Damage
{variant:2}+(15-25)% to Fire Damage over Time Multiplier
Adds (4-6) to (7-9) Fire Damage to Spells
{variant:1}(40-50)% increased Burning Damage
{variant:2}(20-30)% increased Burning Damage
(16-22)% chance to Ignite
]],[[
Eclipse Solaris
Crystal Wand
Upgrade: Upgrades to unique{Corona Solaris} via prophecy{Blinding Light}
Variant: Pre 2.2.0
Variant: Pre 2.3.0
Variant: Pre 3.10.0
Variant: Current
Requires Level 45, 146 Int
Implicits: 2
{variant:1,2}(14-18)% increased Spell Damage
{variant:3,4}(29-33)% increased Spell Damage
{variant:1,2,3}Adds (18-22) to (36-44) Physical Damage
{variant:4}Adds (30-45) to (60-80) Fire Damage
{variant:4}(6-10)% increased Attack Speed
{variant:1}+(18-30)% to Global Critical Strike Multiplier
{variant:2,3,4}+(27-33)% to Global Critical Strike Multiplier
20% increased Light Radius
Nearby Enemies are Blinded
(120-140)% increased Critical Strike Chance against Blinded Enemies
]],[[
Corona Solaris
Crystal Wand
Source: Upgraded from unique{Eclipse Solaris} via prophecy{Blinding Light}
Variant: Pre 3.10.0
Variant: Current
Requires Level 63, 146 Int
Implicits: 1
(29-33)% increased Spell Damage
Triggers Level 20 Blinding Aura when Equipped
{variant:1}Adds (18-22) to (36-44) Physical Damage
{variant:2}Adds (30-45) to (60-80) Fire Damage
{variant:2}(6-10)% increased Attack Speed
+(27-33)% to Global Critical Strike Multiplier
20% increased Light Radius
(120-140)% increased Critical Strike Chance against Blinded Enemies
Increases and Reductions to Light Radius also apply to Accuracy
Adds (145-157) to (196-210) Fire Damage to Hits with this Weapon against Blinded Enemies
]],[[
Lifesprig
Driftwood Wand
Requires Level 2
Implicits: 1
(8-12)% increased Spell Damage
+1 to Level of Socketed Spell Gems
(20-28)% increased Spell Damage
(5-8)% increased Cast Speed
+(15-20) to maximum Life
+(15-20) to maximum Mana
Regenerate (6-8) Life over 1 second for each Spell you Cast
]],[[
Midnight Bargain
Engraved Wand
Variant: Pre 2.3.0
Variant: Pre 3.8.0
Variant: Current
Requires Level 40, 131 Int
Implicits: 2
{variant:1}(12-16)% increased Spell Damage
{variant:2,3}(22-26)% increased Spell Damage
+(10-20) to Intelligence
{variant:1,2}Minions have (10-20)% increased Movement Speed
{variant:3}Minions have (20-30)% increased Movement Speed
{variant:1,2}Minions deal (10-30)% increased Damage
{variant:3}Minions deal (50-70)% increased Damage
+1 to Maximum number of Raised Zombies
+1 to Maximum number of Spectres
+1 to Maximum number of Skeletons
Reserves 30% of Life
Cannot be used with Chaos Inoculation
]],[[
Replica Midnight Bargain
Engraved Wand
League: Heist
Requires Level 40, 131 Int
Implicits: 1
(22-26)% increased Spell Damage
Cannot be used with Chaos Inoculation
+(10-20) to Intelligence
Minions have (40-50)% increased Movement Speed
Minions deal (50-70)% increased Damage
+6 to maximum number of Raging Spirits
Reserves 30% of Life
+3 to maximum number of Summoned Phantasms
]],[[
Moonsorrow
Imbued Wand
Variant: Pre 2.0.0
Variant: Pre 2.3.0
Variant: Pre 3.0.0
Variant: Current
Requires Level 59, 188 Int
Implicits: 2
{variant:1,2}(15-19)% increased Spell Damage
{variant:3,4}(33-37)% increased Spell Damage
{variant:1,2,3}Socketed Gems are supported by level 5 Blind
{variant:4}Socketed Gems are supported by level 20 Blind
(30-40)% increased Spell Damage
{variant:1}125% increased Physical Damage
{variant:2,3}175% increased Physical Damage
{variant:4}(250-275)% increased Physical Damage
+10 to Intelligence
(20-30)% increased Lightning Damage
10% increased Cast Speed
10% chance to Blind Enemies on hit
]],[[
Obliteration
Demon's Horn
Variant: Pre 2.3.0
Variant: Pre 3.10.0
Variant: Current
Requires Level 56, 179 Int
Implicits: 2
{variant:1}(15-18)% increased Spell Damage
{variant:2,3}(31-35)% increased Spell Damage
{variant:1,2}Adds (24-30) to (80-92) Physical Damage
{variant:3}Adds (25-50) to (85-125) Physical Damage
(26-32)% increased Critical Strike Chance
Gain (13-15)% of Physical Damage as Extra Chaos Damage
Enemies you Kill have a 20% chance to Explode, dealing a quarter
of their maximum Life as Chaos Damage
]],[[
Piscator's Vigil
Tornado Wand
Variant: Pre 2.3.0
Variant: Pre 2.6.0
Variant: Current
Requires Level 65, 212 Int
Implicits: 2
{variant:1}(16-19)% increased Spell Damage
{variant:2,3}(35-39)% increased Spell Damage
No Physical Damage
(10-18)% increased Attack Speed
+(340-400) to Accuracy Rating
(20-30)% increased Critical Strike Chance
Attacks with this Weapon have (100-115)% increased Elemental Damage
{variant:3}Attacks with this Weapon Penetrate 5% Elemental Resistances
]],[[
The Poet's Pen
Carved Wand
Requires Level 12, 47 Int
Implicits: 1
(11-15)% increased Spell Damage 
+1 to Level of Socketed Active Skill Gems per 25 Player Levels 
Adds 3 to 5 Physical Damage to Attacks with this Weapon per 3 Player Levels 
(8-12)% increased Attack Speed 
Trigger a Socketed Spell when you Attack with this Weapon, with a 0.15 second Cooldown
]],[[
Reverberation Rod
Spiraled Wand
Upgrade: Upgrades to unique{Amplification Rod} via prophecy{Power Magnified}
Variant: Pre 2.3.0
Variant: Pre 3.11.0
Variant: Current
Requires Level 24, 83 Int
Implicits: 2
{variant:1}(10-14)% increased Spell Damage
{variant:2,3}(15-19)% increased Spell Damage
{variant:1,2}+1 to Level of Socketed Gems
{variant:3}+2 to Level of Socketed Gems
Socketed Gems are Supported by Level 10 Spell Echo
+(10-30) to Intelligence
]],[[
Relic of the Pact
Spiraled Wand
League: Ultimatum
Requires Level 24, 83 Int
Implicits: 1
(15-19)% increased Spell Damage
Grants Level 1 Blood Sacrament Skill
Your Critical Strike Chance is Lucky while on Low Life
]],[[
Amplification Rod
Spiraled Wand
Source: Upgraded from unique{Reverberation Rod} using prophecy{Power Magnified}
Variant: Pre 3.11.0
Variant: Current
Requires Level 36, 83 Int
Implicits: 1
(15-19)% increased Spell Damage
{variant:1}+1 to Level of Socketed Gems
{variant:2}+2 to Level of Socketed Gems
Socketed Gems are Supported by Level 10 Intensify
Socketed Gems are Supported by Level 10 Spell Echo
Socketed Gems are Supported by Level 10 Controlled Destruction
+(10-30) to Intelligence
]],[[
Shade of Solaris
Sage Wand
Variant: Pre 3.5.0
Variant: Current
Requires Level 30, 119 Int
Implicits: 1
(17-21)% increased Spell Damage
Gain (10-20)% of Elemental Damage as Extra Chaos Damage
Critical Strikes deal no Damage
{variant:1}120% increased Spell Damage if you've dealt a Critical Strike Recently
{variant:2}200% increased Spell Damage if you've dealt a Critical Strike in the past 8 seconds
]],[[
Shimmeron
Tornado Wand
Source: Drops from unique{The Elder} (Tier 6+)
Variant: Pre 3.4.0
Variant: Current
Requires Level 65, 212 Int
Implicits: 1
(35-39)% increased Spell Damage 
(30-40)% increased Spell Damage 
Adds (26-35) to (95-105) Lightning Damage to Spells 
+(6-10)% to Critical Strike Multiplier per Power Charge 
+0.3% Critical Strike Chance per Power Charge 
2% additional Chance to Block Spells per Power Charge 
Adds 3 to 9 Lightning Damage to Spells per Power Charge 
{variant:1}400 Lightning Damage taken per second per Power Charge if you've dealt a Critical Strike Recently
{variant:2}200 Lightning Damage taken per second per Power Charge if your Skills have dealt a Critical Strike Recently
Elder Item
]],[[
Storm Prison
Carved Wand
Variant: Pre 2.3.0
Variant: Current
Requires Level 12, 47 Int
Implicits: 2
{variant:1}(9-13)% increased Spell Damage
{variant:2}(11-15)% increased Spell Damage
(40-60)% increased Physical Damage
Adds 1 to (35-45) Lightning Damage
(15-25)% increased Mana Regeneration Rate
+1 Maximum Power Charge
(25-35)% chance to gain a Power Charge on Kill
]],[[
Tulborn
Spiraled Wand
League: Breach
Source: Drops in Tul Breach or from unique{Tul, Creeping Avalanche}
Upgrade: Upgrades to unique{Tulfall} using currency{Blessing of Tul}
Requires Level 24, 83 Int
Implicits: 1
(15-19)% increased Spell Damage
(10-15)% increased Cast Speed
50% chance to gain a Power Charge on Killing a Frozen Enemy
Adds 10 to 20 Cold Damage to Spells per Power Charge
+(20-25) Mana gained on Killing a Frozen Enemy
]],[[
Tulfall
Tornado Wand
League: Breach
Source: Upgraded from unique{Tulborn} using currency{Blessing of Tul}
Requires Level 65, 212 Int
Implicits: 1
(35-39)% increased Spell Damage
(10-15)% increased Cast Speed
50% chance to gain a Power Charge on Killing a Frozen Enemy
Adds 15 to 25 Cold Damage to Spells per Power Charge
Lose all Power Charges on reaching Maximum Power Charges
Gain a Frenzy Charge on reaching Maximum Power Charges
(10-15)% increased Cold Damage per Frenzy Charge
]],[[
Replica Tulfall
Tornado Wand
League: Heist
Requires Level 65, 212 Int
Implicits: 1
(35-39)% increased Spell Damage
(15-25)% increased Cast Speed
Lose all Power Charges on reaching Maximum Power Charges
Gain a Frenzy Charge on reaching Maximum Power Charges
(15-20)% increased Cold Damage per Frenzy Charge
50% chance to gain a Power Charge when you Hit a Frozen Enemy
Take 500 Cold Damage on reaching Maximum Power Charges
]],[[
Twyzel
Sage Wand
Variant: Pre 2.3.0
Variant: Current
Requires Level 30, 119 Int
Implicits: 2
{variant:1}(11-14)% increased Spell Damage
{variant:2}(17-21)% increased Spell Damage
(80-120)% increased Physical Damage
Adds (5-8) to (13-17) Physical Damage
(5-10)% increased Attack Speed
(10-20)% increased Critical Strike Chance
Socketed Gems fire an additional Projectile
]],[[
Replica Twyzel
Sage Wand
League: Heist
Requires Level 30, 119 Int
Implicits: 1
(17-21)% increased Spell Damage
(5-10)% increased Attack Speed
(20-40)% increased Critical Strike Chance
Attacks fire an additional Projectile
]],[[
Void Battery
Prophecy Wand
Variant: Pre 2.3.0
Variant: Current
Requires Level 68, 245 Int
Implicits: 2
{variant:1}(16-20)% increased Spell Damage
{variant:2}(36-40)% increased Spell Damage
80% reduced Spell Damage
(10-20)% increased Cast Speed
(50-65)% increased Global Critical Strike Chance
+(40-50) to maximum Mana
+1 to Maximum Power Charges
25% increased Spell Damage per Power Charge
]],
}

==> PathOfBuildingCommunity-Portable-2.14.0.zip: Data/Uniques/wand.lua <==
﻿-- Item data (c) Grinding Gear Games

return {
-- Weapon: Wand
[[
Abberath's Horn
Goat's Horn
Variant: Pre 2.3.0
Variant: Current
Requires Level 6, 29 Int
Implicits: 2
{variant:1}(9-12)% increased Spell Damage
{variant:2}(10-14)% increased Spell Damage
(20-30)% increased Fire Damage
Adds (4-6) to (8-12) Fire Damage to Spells
(40-60)% increased Global Critical Strike Chance
+10 Life Gained on Killing Ignited Enemies
25% reduced Ignite Duration on Enemies
]],[[
Apep's Rage
Opal Wand
Variant: Pre 2.3.0
Variant: Pre 3.7.0
Variant: Pre 3.11.0
Variant: Current
Requires Level 62, 212 Int
Implicits: 2
{variant:1}(17-20)% increased Spell Damage
{variant:2,3,4}(38-42)% increased Spell Damage
{variant:1,2}Adds (50-65) to (90-105) Chaos Damage to Spells
{variant:3,4}Adds (90-130) to (140-190) Chaos Damage to Spells
(25-30)% increased Cast Speed
+(5-10)% to Chaos Resistance
{variant:1,2,3}40% increased Mana Cost of Skills
{variant:4}Lose 40 Mana when you use a Skill
{variant:3,4}Poisons you inflict deal Damage 20% faster
]],[[
Ashcaller
Quartz Wand
Variant: Pre 3.8.0
Variant: Current
Requires Level 18, 65 Int
Implicits: 1
(18-22)% increased Spell Damage
10% chance to Trigger Level 8 Summon Raging Spirit on Kill
{variant:1}Adds (10-14) to (18-22) Fire Damage
{variant:2}+(15-25)% to Fire Damage over Time Multiplier
Adds (4-6) to (7-9) Fire Damage to Spells
{variant:1}(40-50)% increased Burning Damage
{variant:2}(20-30)% increased Burning Damage
(16-22)% chance to Ignite
]],[[
Eclipse Solaris
Crystal Wand
Variant: Pre 2.2.0
Variant: Pre 2.3.0
Variant: Pre 3.10.0
Variant: Current
Requires Level 45, 146 Int
Implicits: 2
{variant:1,2}(14-18)% increased Spell Damage
{variant:3,4}(29-33)% increased Spell Damage
{variant:1,2,3}Adds (18-22) to (36-44) Physical Damage
{variant:4}Adds (30-45) to (60-80) Fire Damage
{variant:4}(6-10)% increased Attack Speed
{variant:1}+(18-30)% to Global Critical Strike Multiplier
{variant:2,3,4}+(27-33)% to Global Critical Strike Multiplier
20% increased Light Radius
Nearby Enemies are Blinded
(120-140)% increased Critical Strike Chance against Blinded Enemies
]],[[
Corona Solaris
Crystal Wand
Source: No longer obtainable
Variant: Pre 3.10.0
Variant: Pre 3.17.0
Requires Level 63, 146 Int
Implicits: 1
(29-33)% increased Spell Damage
Triggers Level 20 Blinding Aura when Equipped
{variant:1}Adds (18-22) to (36-44) Physical Damage
{variant:2}Adds (30-45) to (60-80) Fire Damage
{variant:2}(6-10)% increased Attack Speed
+(27-33)% to Global Critical Strike Multiplier
20% increased Light Radius
(120-140)% increased Critical Strike Chance against Blinded Enemies
Increases and Reductions to Light Radius also apply to Accuracy
Adds (145-157) to (196-210) Fire Damage to Hits with this Weapon against Blinded Enemies
]],[[
Lifesprig
Driftwood Wand
Requires Level 2
Implicits: 1
(8-12)% increased Spell Damage
+1 to Level of Socketed Spell Gems
(20-28)% increased Spell Damage
(5-8)% increased Cast Speed
+(15-20) to maximum Life
+(15-20) to maximum Mana
Regenerate (6-8) Life over 1 second for each Spell you Cast
]],[[
Midnight Bargain
Engraved Wand
Variant: Pre 2.3.0
Variant: Pre 3.8.0
Variant: Current
Requires Level 40, 131 Int
Implicits: 2
{variant:1}(12-16)% increased Spell Damage
{variant:2,3}(22-26)% increased Spell Damage
+(10-20) to Intelligence
{variant:1,2}Minions have (10-20)% increased Movement Speed
{variant:3}Minions have (20-30)% increased Movement Speed
{variant:1,2}Minions deal (10-30)% increased Damage
{variant:3}Minions deal (50-70)% increased Damage
+1 to Maximum number of Raised Zombies
+1 to Maximum number of Spectres
+1 to Maximum number of Skeletons
Reserves 30% of Life
Cannot be used with Chaos Inoculation
]],[[
Replica Midnight Bargain
Engraved Wand
League: Heist
Requires Level 40, 131 Int
Implicits: 1
(22-26)% increased Spell Damage
Cannot be used with Chaos Inoculation
+(10-20) to Intelligence
Minions have (40-50)% increased Movement Speed
Minions deal (50-70)% increased Damage
+6 to maximum number of Raging Spirits
Reserves 30% of Life
+3 to maximum number of Summoned Phantasms
]],[[
Moonsorrow
Imbued Wand
Variant: Pre 2.0.0
Variant: Pre 2.3.0
Variant: Pre 3.0.0
Variant: Current
Requires Level 59, 188 Int
Implicits: 2
{variant:1,2}(15-19)% increased Spell Damage
{variant:3,4}(33-37)% increased Spell Damage
{variant:1,2,3}Socketed Gems are supported by level 5 Blind
{variant:4}Socketed Gems are supported by level 20 Blind
(30-40)% increased Spell Damage
{variant:1}125% increased Physical Damage
{variant:2,3}175% increased Physical Damage
{variant:4}(250-275)% increased Physical Damage
+10 to Intelligence
(20-30)% increased Lightning Damage
10% increased Cast Speed
10% chance to Blind Enemies on hit
]],[[
Obliteration
Demon's Horn
Variant: Pre 2.3.0
Variant: Pre 3.10.0
Variant: Current
Requires Level 56, 179 Int
Implicits: 2
{variant:1}(15-18)% increased Spell Damage
{variant:2,3}(31-35)% increased Spell Damage
{variant:1,2}Adds (24-30) to (80-92) Physical Damage
{variant:3}Adds (25-50) to (85-125) Physical Damage
(26-32)% increased Critical Strike Chance
Gain (13-15)% of Physical Damage as Extra Chaos Damage
Enemies you Kill have a 20% chance to Explode, dealing a quarter
of their maximum Life as Chaos Damage
]],[[
Piscator's Vigil
Tornado Wand
Variant: Pre 2.3.0
Variant: Pre 2.6.0
Variant: Current
Requires Level 65, 212 Int
Implicits: 2
{variant:1}(16-19)% increased Spell Damage
{variant:2,3}(35-39)% increased Spell Damage
No Physical Damage
(10-18)% increased Attack Speed
+(340-400) to Accuracy Rating
(20-30)% increased Critical Strike Chance
Attacks with this Weapon have (100-115)% increased Elemental Damage
{variant:3}Attacks with this Weapon Penetrate 5% Elemental Resistances
]],[[
The Poet's Pen
Carved Wand
Requires Level 12, 47 Int
Implicits: 1
(11-15)% increased Spell Damage 
+1 to Level of Socketed Active Skill Gems per 25 Player Levels 
Adds 3 to 5 Physical Damage to Attacks with this Weapon per 3 Player Levels 
(8-12)% increased Attack Speed 
Trigger a Socketed Spell when you Attack with this Weapon, with a 0.25 second Cooldown
]],[[
Reverberation Rod
Spiraled Wand
Variant: Pre 2.3.0
Variant: Pre 3.11.0
Variant: Current
Requires Level 24, 83 Int
Implicits: 2
{variant:1}(10-14)% increased Spell Damage
{variant:2,3}(15-19)% increased Spell Damage
{variant:1,2}+1 to Level of Socketed Gems
{variant:3}+2 to Level of Socketed Gems
Socketed Gems are Supported by Level 10 Spell Echo
+(10-30) to Intelligence
]],[[
Relic of the Pact
Spiraled Wand
League: Ultimatum
Requires Level 24, 83 Int
Implicits: 1
(15-19)% increased Spell Damage
Grants Level 1 Blood Sacrament Skill
Your Critical Strike Chance is Lucky while on Low Life
]],[[
Amplification Rod
Spiraled Wand
Source: Drops from any endgame map boss
Variant: Pre 3.11.0
Variant: Current
Requires Level 36, 83 Int
Implicits: 1
(15-19)% increased Spell Damage
{variant:1}+1 to Level of Socketed Gems
{variant:2}+2 to Level of Socketed Gems
Socketed Gems are Supported by Level 10 Intensify
Socketed Gems are Supported by Level 10 Spell Echo
Socketed Gems are Supported by Level 10 Controlled Destruction
+(10-30) to Intelligence
]],[[
Shade of Solaris
Sage Wand
Variant: Pre 3.5.0
Variant: Current
Requires Level 30, 119 Int
Implicits: 1
(17-21)% increased Spell Damage
Gain (10-20)% of Elemental Damage as Extra Chaos Damage
Critical Strikes deal no Damage
{variant:1}120% increased Spell Damage if you've dealt a Critical Strike Recently
{variant:2}200% increased Spell Damage if you've dealt a Critical Strike in the past 8 seconds
]],[[
Shimmeron
Tornado Wand
Source: Drops from unique{The Elder} (Tier 6+)
Variant: Pre 3.4.0
Variant: Current
Requires Level 65, 212 Int
Implicits: 1
(35-39)% increased Spell Damage 
(30-40)% increased Spell Damage 
Adds (26-35) to (95-105) Lightning Damage to Spells 
+(6-10)% to Critical Strike Multiplier per Power Charge 
+0.3% Critical Strike Chance per Power Charge 
2% additional Chance to Block Spells per Power Charge 
Adds 3 to 9 Lightning Damage to Spells per Power Charge 
{variant:1}400 Lightning Damage taken per second per Power Charge if you've dealt a Critical Strike Recently
{variant:2}200 Lightning Damage taken per second per Power Charge if your Skills have dealt a Critical Strike Recently
Elder Item
]],[[
Storm Prison
Carved Wand
Variant: Pre 2.3.0
Variant: Current
Requires Level 12, 47 Int
Implicits: 2
{variant:1}(9-13)% increased Spell Damage
{variant:2}(11-15)% increased Spell Damage
(40-60)% increased Physical Damage
Adds 1 to (35-45) Lightning Damage
(15-25)% increased Mana Regeneration Rate
+1 Maximum Power Charge
(25-35)% chance to gain a Power Charge on Kill
]],[[
Tulborn
Spiraled Wand
League: Breach
Source: Drops in Tul Breach or from unique{Tul, Creeping Avalanche}
Upgrade: Upgrades to unique{Tulfall} using currency{Blessing of Tul}
Requires Level 24, 83 Int
Implicits: 1
(15-19)% increased Spell Damage
(10-15)% increased Cast Speed
50% chance to gain a Power Charge on Killing a Frozen Enemy
Adds 10 to 20 Cold Damage to Spells per Power Charge
+(20-25) Mana gained on Killing a Frozen Enemy
]],[[
Tulfall
Tornado Wand
Variant: Pre 3.16.0
Variant: Current
League: Breach
Source: Upgraded from unique{Tulborn} using currency{Blessing of Tul}
Requires Level 65, 212 Int
Implicits: 1
(35-39)% increased Spell Damage
(10-15)% increased Cast Speed
{variant:1}50% chance to gain a Power Charge on Killing a Frozen Enemy
{variant:2}Gain a Power Charge on Killing a Frozen Enemy
Adds 15 to 25 Cold Damage to Spells per Power Charge
Lose all Power Charges on reaching Maximum Power Charges
Gain a Frenzy Charge on reaching Maximum Power Charges
{variant:1}(10-15)% increased Cold Damage per Frenzy Charge
{variant:1}(15-20)% increased Cold Damage per Frenzy Charge
]],[[
Replica Tulfall
Tornado Wand
League: Heist
Requires Level 65, 212 Int
Implicits: 1
(35-39)% increased Spell Damage
(15-25)% increased Cast Speed
Lose all Power Charges on reaching Maximum Power Charges
Gain a Frenzy Charge on reaching Maximum Power Charges
(15-20)% increased Cold Damage per Frenzy Charge
50% chance to gain a Power Charge when you Hit a Frozen Enemy
Take 500 Cold Damage on reaching Maximum Power Charges
]],[[
Twyzel
Sage Wand
Variant: Pre 2.3.0
Variant: Current
Requires Level 30, 119 Int
Implicits: 2
{variant:1}(11-14)% increased Spell Damage
{variant:2}(17-21)% increased Spell Damage
(80-120)% increased Physical Damage
Adds (5-8) to (13-17) Physical Damage
(5-10)% increased Attack Speed
(10-20)% increased Critical Strike Chance
Socketed Gems fire an additional Projectile
]],[[
Replica Twyzel
Sage Wand
League: Heist
Requires Level 30, 119 Int
Implicits: 1
(17-21)% increased Spell Damage
(5-10)% increased Attack Speed
(20-40)% increased Critical Strike Chance
Attacks fire an additional Projectile
]],[[
Void Battery
Prophecy Wand
Variant: Pre 2.3.0
Variant: Current
Requires Level 68, 245 Int
Implicits: 2
{variant:1}(16-20)% increased Spell Damage
{variant:2}(36-40)% increased Spell Damage
80% reduced Spell Damage
(10-20)% increased Cast Speed
(50-65)% increased Global Critical Strike Chance
+(40-50) to maximum Mana
+1 to Maximum Power Charges
25% increased Spell Damage per Power Charge
]],
}
